@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 #! python3  # noqa E265
 
 """
@@ -202,9 +201,8 @@ class ApiFeatureAttribute:
         if not attribute.dataType:
             logger.warning(
                 ValueError(
-                    "Attribute dataType is missing. An empty string '\"\"' (but != None) will be used.".format(
-                        attribute.dataType
-                    )
+                    "Attribute dataType is missing. "
+                    "An empty string '\"\"' (but != None) will be used."
                 )
             )
             attribute.dataType = ""
@@ -342,7 +340,11 @@ class ApiFeatureAttribute:
 
     # -- Extra methods as helpers --------------------------------------------------
     def import_from_dataset(
-        self, metadata_source: Metadata, metadata_dest: Metadata, mode: str = "add"
+        self,
+        metadata_source: Metadata,
+        metadata_dest: Metadata,
+        mode: str = "add",
+        case_sensitive_matching: bool = True,
     ) -> bool:
         """Import feature-attributes from another vector metadata.
 
@@ -353,6 +355,8 @@ class ApiFeatureAttribute:
             - 'add': add the attributes except those with a duplicated name
             - 'update': update only the attributes with the same name
             - 'update_or_add': update the attributes with the same name or create
+        : param bool case_sensitive_matching: False to make featureattributes's name 
+        matching case-insensitive when mode == "update"
 
         :raises TypeError: if one metadata is not a vector
         :raises ValueError: if mode is not one of accepted value
@@ -387,6 +391,9 @@ class ApiFeatureAttribute:
         attributes_source = self.listing(metadata_source)
         attributes_dest = self.listing(metadata_dest)
         attributes_dest_names = [attr.get("name") for attr in attributes_dest]
+        attributes_dest_names_low = [
+            attr.get("name").lower() for attr in attributes_dest
+        ]
 
         # according to the selected mode
         if mode == "add":
@@ -419,16 +426,30 @@ class ApiFeatureAttribute:
                             if attr.get("name") == attr_src.name
                         ][0]
                     )
-                    attr_dst.alias = attr_src.alias
-                    attr_dst.dataType = attr_src.dataType
-                    attr_dst.description = attr_src.description
-                    attr_dst.language = attr_src.language
-                    self.update(metadata=metadata_dest, attribute=attr_dst)
-                    logger.debug(
-                        "Attribute with the same name ({}) spotted. It has been updated.".format(
-                            attr_dst.name
-                        )
+                elif (
+                    attr_src.name.lower() in attributes_dest_names_low
+                    and not case_sensitive_matching
+                ):
+                    attr_dst = FeatureAttribute(
+                        **[
+                            attr
+                            for attr in attributes_dest
+                            if attr.get("name").lower() == attr_src.name.lower()
+                        ][0]
                     )
+                else:
+                    continue
+
+                attr_dst.alias = attr_src.alias
+                attr_dst.dataType = attr_src.dataType
+                attr_dst.description = attr_src.description
+                attr_dst.language = attr_src.language
+                self.update(metadata=metadata_dest, attribute=attr_dst)
+                logger.debug(
+                    "Attribute with the same name ({}) spotted. It has been updated.".format(
+                        attr_dst.name
+                    )
+                )
         elif mode == "update_or_add":
             for attribute in attributes_source:
                 attr_src = FeatureAttribute(**attribute)
